package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````91<``#0```"0@0````0`!30`(``)
M`"@`&P`:``$``'`D>P``)'L``"1[```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$````````````````````P>P``,'L```4```````$`
M`0```)Q]``"<?0$`G'T!`*0"``"\$@``!@```````0`"````I'T``*1]`0"D
M?0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DG'T`
M`)Q]`0"<?0$`9`(``&0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`W`*.4AMT]**+=,33"U"?9841YS`$
M````$`````$```!'3E4```````,````"`````````!$```!0````"`````@`
M```!D!`$)4`$@"B```&@AE"`@`$```LH!(PXH!)%B@``"%````!1````5```
M`%@```!9````8````&$```!B````9````&4`````````9P```&@```!I````
M:P```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M````````````:!(````````#``L```````"``0```````P`6`)`"````````
M`````!(````^`P`````````````2````$@,`````````````(@```%<#````
M`````````!$```#:`P`````````````2````$0``````````````(````.\!
M`````````````!(```#D`@`````````````2````+P,`````````````$@``
M`!$!`````````````!(```"'`P`````````````1````M```````````````
M$@```*L"`````````````!(```"#`0`````````````2````EP(`````````
M````$@```(0``````````````!(````,`0`````````````2````L@(`````
M````````$@```'0"`````````````!(````Z`@`````````````2````80,`
M````````````$@```$L"`````````````!(```!8`@`````````````2````
M`0$`````````````$0```&<!`````````````!(```#C```````````````1
M````-0$`````````````$@```.L"`````````````!(```#=`@``````````
M```1````]`(`````````````$@```,(``````````````!(```"Q`0``````
M```````2````"P(`````````````$@```)X!`````````````!(```#+`@``
M```````````2````$P(`````````````$@```*H!`````````````!(```!%
M`P`````````````2````0P$`````````````$@```"T``````````````"``
M``!M`@`````````````2````)`(`````````````$@```(("````````````
M`!(```"\`0`````````````1````9```````````````$@````$#````````
M`````!(```"3```````````````2````]`$`````````````$@```"$#````
M`````````!(```"?```````````````2````7`$`````````````$@```%("
M`````````````!(```")`@`````````````2````(@$`````````````$@``
M`%8``````````````!(````6`0`````````````2````DP$`````````````
M$@```)T"`````````````!(```#P```````````````2````9@(`````````
M````$@```#<#`````````````!(```![`@`````````````2````=0$`````
M````````$@```',``````````````!(```!8`P`````````````A````"`,`
M````````````$@```-0``````````````!(```!3`0`````````````2````
M/```````````````(````%D#`````````````!$```#3`@`````````````2
M````*0(`````````````$@```&`"`````````````!(````%`@``````````
M```2````P`(`````````````$@```#$"`````````````!(```#;`0``````
M```````2````]P,``%B0`0``````$``7`.,#``#1.@``4````!(`#0`;!```
M;3```(P'```2``T`4@,``)D5``#,`0``$@`-`*D#```=*P``!````!(`#0"Z
M`P``0(`!```````0`!<`H@0``"$K``#(`0``$@`-`,\$``#Y-P``V`(``!(`
M#0".!```0(`!```````0`!<``@0``.DL```6````$@`-`#4$``!\.P``!```
M`!$`#P!T!```6)`!```````0`!<`>00``%B0`0``````$``7`)H$``#U*0``
M.````!(`#0"O!```P2\``*P````2``T`P00``#TO``!T````$@`-`"@$````
M@`$``````!``%@`/!````2T``+0````2``T`[P,``$"``0``````$``6`&H$
M```\@`$`!````!$`%@"9`P``83L```(````2``T`6@0``"$[``!`````$@`-
M`"X$``!E%P```````!(`#0`J!````(`!```````@`!8`R`,``+$O```0````
M$@`-`/8#``!8D`$``````!``%P!$!```>2H``*0````2``T`@00``+4M``"(
M`0``$@`-``!L:6)P97)L+G-O+C4N,S``7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B
M;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L
M;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S
M=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR
M7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K
M`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?
M;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO
M861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C
M`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P
M96-I9FEC`')E860`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L<V5E:S8T`&]P
M96XV-`!L:6)C+G-O+C8`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?
M8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E
M='!I9`!S=')D=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER
M`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V
M-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?
M;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?
M<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R
M=%]M86EN`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!L9"UL:6YU>"UA
M<FUH9BYS;RXS`%]?<W1A8VM?8VAK7V=U87)D`%]?;&EB8U]C<W5?9FEN:0!P
M87)?8W5R<F5N=%]E>&5C`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R
M;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A
M<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T
M87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI
M8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E
M;G8`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P
M7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`
M1TQ)0D-?,BXT```````````"``(``@`"``(````#``(``@`"``0````"````
M`@```````@`"``(``@`"``(````````````"``(``@```````P````(``P`"
M``(```````(``@`"```````"`````P`"```````"``(````````````"````
M`@`"``(```````(``@`````````"``(``@`"``,``@`"``,``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$`<P,``!`````@````%&EI#0``!`#E!`````````$``0#+`0``$```
M`"`````4:6D-```#`.4$`````````0`!`!H"```0`````````!1I:0T```(`
MY00```````"<?0$`%P```*!]`0`7````P'\!`!<```#H?P$`%P```/!_`0`7
M````!(`!`!<````,@`$`%P```!"``0`7````&(`!`!<````<@`$`%P```""`
M`0`7````)(`!`!<````H@`$`%P```#"``0`7````-(`!`!<````\@`$`%P``
M`,1_`0`5!0``R'\!`!4(``#,?P$`%0T``-!_`0`5$```U'\!`!4:``#8?P$`
M%1P``-Q_`0`5'P``X'\!`!4J``#D?P$`%2X``.Q_`0`5.```]'\!`!5"``#X
M?P$`%4<``/Q_`0`52```P'X!`!8#``#$?@$`%@0``,A^`0`6!0``S'X!`!8'
M``#0?@$`%@D``-1^`0`6"@``V'X!`!8+``#<?@$`%@P``.!^`0`6#@``Y'X!
M`!8/``#H?@$`%A$``.Q^`0`6$@``\'X!`!83``#T?@$`%A0``/A^`0`6%0``
M_'X!`!86````?P$`%A<```1_`0`6&```"'\!`!89```,?P$`%AL``!!_`0`6
M'0``%'\!`!8>```8?P$`%B```!Q_`0`6(0``('\!`!8B```D?P$`%B,``"A_
M`0`6)```+'\!`!8E```P?P$`%B8``#1_`0`6)P``.'\!`!8H```\?P$`%BD`
M`$!_`0`6*@``1'\!`!8K``!(?P$`%BP``$Q_`0`6+0``4'\!`!8O``!4?P$`
M%C```%A_`0`6,0``7'\!`!8R``!@?P$`%C,``&1_`0`6-```:'\!`!8U``!L
M?P$`%C8``'!_`0`6-P``='\!`!8Y``!X?P$`%CH``'Q_`0`6.P``@'\!`!8\
M``"$?P$`%CT``(A_`0`6/@``C'\!`!8_``"0?P$`%D```)1_`0`600``F'\!
M`!9$``"<?P$`%D4``*!_`0`61@``I'\!`!9)``"H?P$`%DH``*Q_`0`62P``
ML'\!`!9,``"T?P$`%DT``+A_`0`63@``O'\!`!9/```(0"WI3@$`ZPB`O>@$
MX"WE!."?Y0[@C^`(\+[E,&P!``#&C^(6RHSB,/R\Y0#&C^(6RHSB*/R\Y0#&
MC^(6RHSB(/R\Y0#&C^(6RHSB&/R\Y0#&C^(6RHSB$/R\Y0#&C^(6RHSB"/R\
MY0#&C^(6RHSB`/R\Y0#&C^(6RHSB^/N\Y0#&C^(6RHSB\/N\Y0#&C^(6RHSB
MZ/N\Y0#&C^(6RHSBX/N\Y0#&C^(6RHSBV/N\Y0#&C^(6RHSBT/N\Y0#&C^(6
MRHSBR/N\Y7A'_><`QH_B%LJ,XKS[O.4`QH_B%LJ,XK3[O.5X1_WG`,:/XA;*
MC.*H^[SE`,:/XA;*C.*@^[SE`,:/XA;*C.*8^[SE`,:/XA;*C.*0^[SE`,:/
MXA;*C.*(^[SE`,:/XA;*C.*`^[SE`,:/XA;*C.)X^[SE`,:/XA;*C.)P^[SE
M`,:/XA;*C.)H^[SE`,:/XA;*C.)@^[SE`,:/XA;*C.)8^[SE`,:/XA;*C.)0
M^[SE`,:/XA;*C.)(^[SE`,:/XA;*C.)`^[SE`,:/XA;*C.(X^[SE`,:/XA;*
MC.(P^[SE`,:/XA;*C.(H^[SE`,:/XA;*C.(@^[SE`,:/XA;*C.(8^[SE`,:/
MXA;*C.(0^[SE`,:/XA;*C.((^[SE`,:/XA;*C.(`^[SE`,:/XA;*C.+X^KSE
M`,:/XA;*C.+P^KSE`,:/XA;*C.+H^KSE`,:/XA;*C.+@^KSE>$?]YP#&C^(6
MRHSBU/J\Y0#&C^(6RHSBS/J\Y0#&C^(6RHSBQ/J\Y0#&C^(6RHSBO/J\Y0#&
MC^(6RHSBM/J\Y0#&C^(6RHSBK/J\Y0#&C^(6RHSBI/J\Y0#&C^(6RHSBG/J\
MY0#&C^(6RHSBE/J\Y0#&C^(6RHSBC/J\Y0#&C^(6RHSBA/J\Y0#&C^(6RHSB
M?/J\Y0#&C^(6RHSB=/J\Y0#&C^(6RHSB;/J\Y0#&C^(6RHSB9/J\Y0#&C^(6
MRHSB7/J\Y0#&C^(6RHSB5/J\Y0#&C^(6RHSB3/J\Y0#&C^(6RHSB1/J\Y0#&
MC^(6RHSB//J\Y0#&C^(6RHSB-/J\Y0#&C^(6RHSB+/J\Y0````#PM8FP7$Q=
M2WQ$!9`$D06H`Y($J>-8`ZI93!MH!Y-/\``#__="[U=*?$172Z)8X%@11@+P
MR_I52^-8'G@`+FW04TOE6"AH__?4[P-&*&B3^,8C0O`"`H/XQB/_]\KO!9L%
M,[/Q@$^0^,8C0O`!`H#XQB-VTI@`!"3_]]KN14D$GGE$14H/:'I$-6A$27E$
M`T9#2,/I`2<%FGA$P>D!0P$J'6#"OS$=`_$,!`;K@@;88`7=4?@$6XY"1/@$
M7_G1`O&`03A-`S$`)'U$`)1#^"%``S(U22AI>43_]RKO!$9HLS)-!JY]1"AI
M__=X[C!(,49X1`#P/_\PLRY+>T08:?_W0.[_]PKO+$H<2WI$TU@::`>;6D`N
MT2!&";#PO?_W?.XF2GI$$&$0L__W).X82^58*&C_]U[O@/AQ9X/G*&G_]R[O
M!$;,Y^AH$+$"\/7YT^<;2#%&>$0`\`W_Z&``*,O0\^<82QA(X5AX1/_WO.X!
M(/_WCN[_]QCN$&D!`!@!``#P:`$`.`$``$`!```D`0``(`$``"!J`0"6*```
M'&H!`(@H``#@:0$`NQ,``,1I`0#P)0``KFD!``YH`0"&:0$`*"4``#`!``#L
M)@``3_``"T_P``X"O&I&!+0!M-_X)*`(HYI$W_@@P%KX#,!-^`3-!DM:^`,P
M!DA:^```__<P[O_WWNX89P$`#`$``#0!```\`0``%#"?Y10@G^4#,(_@`B"3
MYP``4N,>_R\!$?__ZOAF`0`L`0``!D@'2WA$!TI[1(-">D0#T`5+TU@#L1A'
M<$<`OVAH`0!D:`$`U&8!`!0!```(2`E)>$0)2GE$"1IZ1,L/`^NA`4D0`]`%
M2]-8`[$81W!'`+\\:`$`.&@!`*AF`0!$`0``"+4*2PI*>T1Z1!MX:[D)2]-8
M([$(2WM$&&C_]RKM__>__P9+`2)[1!IP"+T&:`$`>&8!`!`!``"Z9P$`YF<!
M`,3G`+\`````+>GP3ZWU(WW?^'Q,`/%``=_X>#QN1GQ$`/&`##)&`"?C6!MH
MH9-/\``#4>D"5`@Q84578"VZUV!/ZA0C3^H$+@/T?T,.]'\.0^H48Q5@0^H$
M8P+Q$`)#Z@X#0O@(/.31!O7\=JWQ"`0`)X9&I$94^`@/W/AP(-SX2#"T0MSX
M&%#<^'00@^H"`]SX3""#Z@4#W/@<4(/J``."Z@$"86B"Z@4"3^K3=8+J`0+$
M^(1P1>I"!47J0P/$^(`PU]'>Z0+#<$;>Z0!R3^J<#@9IA6E.ZH-^:T;Y#AQH
MANH%"4?VF1,%:L7V@B-!ZD(1Y!A!ZD<191D)Z@P)21F%:4[JC'X"G(GJ!0F]
M"(;J#@A%ZH)U@FD1ZPD!".H'".081>J'=8CJ!@BD&`2:3^KQ:13K"`2.Z@4(
M%.L)!`CJ`0C2&$_JL0&(Z@X(W?@8D)(93^KT:A+K"`*%Z@$($NL*`@CJ!`@9
MZP,)3^JT!(CJ!0@9ZPX.W?@@D$_J\FH>ZP@.@>H$"![K"@X(Z@((&>L#"4_J
ML@*(Z@$(&>L%!=WX*)!/ZOYJ%>L(!83J`@@5ZPH%".H."!GK`PE/ZKX.B.H$
M"-WX,*`9ZP$!$>L(`8+J#@E/ZO5H">H%"1'K"`@:ZP,*3^JU`8GJ`@D:ZP0$
MW?@XH([J`044ZPD$3^KX:07J"`44ZPD$&NL#"D_JN`B%Z@X%&NL"`MWX0*!2
M&8'J"`E/ZO1E">H$"549&NL#"@I&&NL.#D_JM`'=^$B@B>H"!$_J]6D>ZP0$
MB.H!#A3K"00.Z@4.&NL#"4_JM049ZP()CNH(#D)&W?A0@$_J]&H9ZPX.@>H%
M"1[K"@X)Z@0)&.L#"-WX6*`8ZP((3^JT`HGJ`008ZP0$3^K^:87J`@@4ZPD$
M".H."!KK`PE/ZKX.&>L!"8CJ!0@I1AB=3^KT:AGK"`B"Z@X)&.L*"`GJ!`GM
M&-WX:*!M&$_JM`&)Z@($3^KX:2P9CNH!!13K"00%Z@@%&NL#"4_JN`@9ZP()
M<D;=^'#@54!/ZO1J&>L%!8'J"`D5ZPH%">H$"1[K`P[=^'B@'NL"#D_JM`*)
MZ@$$'NL$!$_J]6F(Z@(.%.L)!`[J!0X:ZP,)3^JU!8[J"`X9ZP$)04;=^("`
M3^KT:AGK#@F"Z@4.&>L*"0[J!`X8ZP,(3^JT!([J`@X8ZP$!W?B(@$_J^6H1
MZPX!A>H$#A'K"@$.Z@D.&.L#"$_JN0F.Z@4.&.L"`MWXD(!/ZO%J$NL.`H3J
M"0X2ZPH"#NH!#ACK`PA/ZK$!&.L%!8[J!`C=^)C@3^KR:A7K"`B)Z@$%&.L*
M"!5`'NL##H7J"04HFQ[K!`Y/ZK("'NL%#D[VH31/ZOAEQO;99![K!0Z!Z@(%
M&QF%Z@@%$^L)"2J;3^JX"!GK!0E/ZOYE&>L%"8+J"`4;&87J#@5;&"R93^J^
M#EL93^KY95L9B.H.!0D9A>H)!8D8+II/ZKD)31E/ZO-A;1B.Z@D!$AE90!+K
M"`@PFD_JLP,8ZP$!3^KU:(GJ`PH1ZP@!$AG=^,B`BNH%"A+K#@)/ZK4%3^KQ
M;A+K"@(2ZPX"@^H%"ACK!`Z*Z@$*W?C0@![K"0Y/ZK$!3^KR:1[K"@[=^.B@
M'NL)#H7J`0D8ZP0(B>H""1CK`P/=^-B`$^L)"4_JL@-/ZOYB&>L"`H'J`PD8
MZP0(B>H."1CK!0@XG4_JO@X8ZPD(3^KR:1CK"0B#Z@X)+1F)Z@():1A/ZK(%
M$>L)`4_J^&*)&([J!0D:ZP0"B>H("=WX\*#2&!+K"0)/ZK@#3^KQ:(7J`PD2
MZP@"&NL$"(GJ`0G=^/B@&.L."$_JL0%/ZO)N&.L)"!CK#@B#Z@$)&NL$#HGJ
M`@D>ZP4.0)U/ZK("'NL)#D_J^&G=^`BA'NL)#H'J`@DM&8GJ"`GK&$_JN`43
MZPD#3^K^:!/K"`."Z@4)&NL$"(GJ#@G=^!"A&.L!`1'K"0E/ZKX!3^KS;H7J
M`0@9ZPX)&NL$#A[K`@*(Z@,(W?@8X1+K"`A/ZK,"3^KY8QCK`PB!Z@(*'NL$
M`XKJ"0K=^"#A71D5ZPH%3^JY`T_J^&D5ZPD%@NH#"1[K!`Z)Z@@)'NL!`=WX
M*.%/ZK@($>L)`4_J]6D1ZPD!@^H("1[K!`Z)Z@4)'NL"#DR:3^JU!1[K"0Y/
MZO%I'NL)#HCJ!0D2&8GJ`0G2&$Z;3^JQ`1+K"0)/ZOYI$NL)`H7J`0D;&8GJ
M#@D3ZP@$W?A`@4_JO@Y/ZO)J%.L)!$OVW$/(]AMS%.L*!$'J#@D8ZP,(JD8)
MZ@()3^JR!1CK"@(!Z@X*W?A(@4GJ"@E.Z@4*$NL)`D_J]&D2ZPD""NH$"@[J
M!0D8ZP,(3^JT!$KJ"0H8ZP$!W?A0D47J!`@:ZP$!3^KR:@CJ`@@1ZPH!!>H$
M"AGK`PE(Z@H(&>L.#D_JL@(8ZPX.W?A8@43J`@I/ZO%I'NL)#@KJ`0H$Z@()
M&.L#"$_JL0%*Z@D*&.L%!=WX8)%"Z@$(&NL%!4_J_FH(Z@X(%>L*!0+J`0H9
MZP,)2.H*"!GK!`1/ZKX.&.L$!-WX:(%!Z@X*3^KU:13K"00*Z@4*`>H."1CK
M`PA/ZK4%2NH)"ACK`@+=^'"13NH%"!KK`@)/ZO1J".H$"!+K"@(.Z@4*&>L#
M"4CJ"@@9ZP$!3^JT!!CK`0'=^'B!1>H$"D_J\FD1ZPD!"NH""@7J!`D8ZP,(
M3^JR`DKJ"0H8ZPX.W?B`D43J`@@:ZPX.3^KQ:@CJ`0@>ZPH.&>L#"03J`@I/
MZK$!2.H*"AGK!07=^(B10NH!"!KK!05/ZOYJ%>L*!0CJ#@@"Z@$*&>L#"4_J
MO@Y(Z@H(&>L$"F2<0>H."4_J]6L8ZPH(">H%"1CK"P@!Z@X*Y!A/ZK4%2>H*
M"J089II.Z@4)&NL$!$_J^&H4ZPH$#NH%"Q+K`PH)Z@@)3^JX`DGJ"PD:ZP$(
M:)E%Z@(*&>L("4_J]&@*Z@0*&>L("<D8!>H""$_JM`1*Z@@($>L.#FJ90NH$
M"ACK#@Y/ZOEH'NL(#@+J!`O)&`KJ"0I/ZKD(31E*Z@L);)E$Z@@*&>L%!4_J
M_FD*Z@X*%>L)!03J"`G)&$_JO@Z)&$KJ"0INFDCJ#@L:ZP$)3^KU:AGK"@D+
MZ@4!TA@(Z@X+3^JU!4'J"PL2&7"93NH%"D_J^60;ZP(""NH)"A(9#NH%"\D8
M3^JY!!'K"`A*Z@L)<IE%Z@0*&>L("$_J\FD8ZPD(!>H$"Q'K`PD*Z@(*3^JR
M`4KJ"PITFAGK#@X:ZPX.1.H!"4_J^&H)Z@@)'NL*#@3J`0K2&$_JN`A)Z@H)
M4AEVG4'J"`H9ZP("3^K^:1+K"0(*Z@X*[1@!Z@@#2NH#"BT9>)M/ZKX.&NL%
M!4SRUA1/ZO)JS/9B)!7K"@6(Z@X)&QF)Z@()61AZFT_JL@)/ZO5J$>L)`8[J
M`@D1ZPH!&QF)Z@4)$^L("'R;3^JU!1CK"0A/ZO%I&.L)"(+J!0D;&8GJ`0D3
MZPX.?IL>ZPD)3^JQ`4_J^&Z%Z@$*&>L.#AL9FAB*Z@@*@)M/ZK@($NL*"D_J
M_F(:ZP("@>H("1L9B>H."5T9@IL5ZPD)3^J^#D_J\F49ZP4%B.H."1L9B>H"
M"5D8A)L1ZPD)3^JR`D_J]6$9ZP$!CNH""1L9B>H%"1/K"`B&FQCK"0E/ZK4%
M3^KQ:!GK"`B"Z@4)&QF)Z@$)$^L.#HB;'NL)"4_JL0%/ZOAN&>L.#H7J`0D;
M&8GJ"`F:&(J;$NL)"4_JN`A/ZOYB&>L"`H'J"`D;&8GJ#@E=&8R;%>L)"4_J
MO@Y/ZO)E&>L%!8CJ#@D;&8GJ`@E9&(Z;$>L)"4_JL@)/ZO5A&>L!`8[J`@D;
M&8GJ!0D3ZP@(D)L8ZPD)3^JU!4_J\6@9ZP@(@NH%"1L9B>H!"1/K#@Z2FQ[K
M"0E/ZK$!3^KX;AGK#@Z%Z@$)&QF)Z@@)FAB4FQ+K"0E/ZK@(3^K^8AGK`@*!
MZ@@)&QF)Z@X)71F6FQ7K"0E/ZKX.3^KR91GK!06(Z@X)&QF)Z@()61B8FQ'K
M"0E/ZK("3^KU81GK`0&.Z@()&QF)Z@4)$^L(")J;&.L)"4_JM05/ZO%H&>L(
M"!L9@NH%"1/K#@Z)Z@$)G)L>ZPD)3^JQ`4_J^&X9ZPX.&QF%Z@$)FAB)Z@@)
MGIL2ZPD)3^K^8AGK`@E/ZK@(&QF!Z@@"VQF"Z@X"6QE/ZKX.FQA/ZOEBFQ@9
MZPP"`V`>ZP8&@VD`)()@`FH8ZP,#@V&)&`Q*"DMZ1`9A1&`!8L1@1&'$841B
MTU@::*&;6D`#T0WU(WV]Z/"/_O<@[R)F`0`8`0``UED!`"WI^$.!1B!+>T0`
M*#?0'TJ;6-/X`("X\0`/,M`">`]&LO$]!1B_`24`*@B_`"6=N=CX`$!LL49&
M*D9)1B!&__<`Z!"Y8UT]*Q#05O@$3P`L\M$@1KWH^(,%1A7X`3\`*QB_/2OY
MT:7K"07AYP$UINL(!BQ$MA`^8"!&O>CX@P1&Y^=$1N7G`+^<60$`2`$``!I*
M&TMZ1'"U@K#36`1&&4UN1AMH`9-/\``#?40Q1B!&__>F_["Q%$L`F.M8&6@!
MZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT3%&($;_]Y#_`"CHT0E*!DMZ1--8
M&F@!FUI``=$"L'"]_O><[A!9`0`8`0``^E@!`$@!``"\6`$`+>GP3PQ&"WB#
ML%A)!4982CTK>40(OP$TW_A8@8I8($;X1!)H`9)/\``"_O?V[FE&!D8H1O_W
M7/^!1@`H5]#^]^SNL$)*TDQ+`)]8^`.`OP`H>+#Q/0(8OP$B`"@(OP`B.K$J
M1A+X`3\`*QB_/2OYT5(;L!S8^`!@$$3^]ZKN\%$`*&O0V/@`("A&`)D0^`$[
M4O@A$#TK&+\`*PMP"=!*'!#X`3L11@`K&+\]*P+X`3OVT0I&/2,+<!3X`3L"
M^`$_`"OYT0`@+4HI2WI$TU@::`&;6D!(T0.PO>CPCPGQ_SD4^`$["?@!/P`K
M^='JYR)+6/@#@-CX`*#:^``PB[-31E/X!"])1@GQ`0D`*OC1`S&)`!M*>D03
M:+.Y"$8!(Q-@_O=6[H-&R+%/ZHD'448Z1O[WP.W(^`"P"?$!`P`B2_@C(,WX
M`)"#YU!&3^J)!_[W_NV#1LCX````*.W13_#_,+'GF48((=3G_O?<[8)8`0`8
M`0``=%@!`$@!``#*5P$`$%D!`#I*.TMZ1"WI\$&>L--8&V@=DT_P``,0L0-X
M!$93N35*,TMZ1--8&F@=FUI`7-$>L+WH\('^]_[M!48`*._0+D]_1"A&_O>:
M[J"SPWP`\1,(+BLVT,-\+BLZT"!&_O<:[@9&0$;^]Q;N,$0",/[W[NT[1D_P
M_S(!(<WX!(``E`9&_O<F[@*J,48#(/[WBNX!,#!&!=`&FP/T<$.S]8!/(-#^
M]XSM,$;^]TKM*$;^]V;N`"C*T2A&_O>2[B!&_O=0[:WGF/@!,``KN]##?"XK
MQ-&8^`$P+BO`T9CX`C``*[#0N^?_]XW_W>?^]UKM#%<!`!@!``#N5@$`V!,`
M`-_X8,`82_Q$$+6<L`1&7/@#,&I&`R`A1AMH&Y-/\``#_O=8[I"Y!)L#]'!#
ML_4@3QB_L_6`3PO0#$H+2WI$TU@::!N;6D`+T1RP$+T`(//G($8"(?[W`NZP
M^H#P0`GKY_[W(.T.5@$`&`$``-A5`0#?^,S`0/;_<BWI\$.M]8!=,$R#L/Q$
M`:X%1B](7/@$0`WU@%-X1`]&,48$,R1H'&!/\``$_O<D[2A+*4I[1`0>.-T$
M\?\XFU@6^`@0T_@`D`&[N/$`#R700D8O(3!&_O?`[?BQ2$;^]PKN0T8R1BE&
M_O?4[1M)#?6`4Q9*!#-Y1(I8$6@::%%`']$-]8!=`["]Z/"#H$8O(4)&,$;^
M]Z#M`"C?T4A&_O?J[3I&*4;^]^+LW^>;6-/X`)!(1O[WWNTZ1BE&_O?6[-3G
M_O>T[`"_D%4!`!@!``"0$@``:%4!`"`!```F50$`$+4(3`A+?$3C6!AH_O?"
M[09*!TL'2:)8>T2]Z!!`>43^]SB]ME0!`"`!```<`0``Y%```+X1```-2PY*
M>T00M8*PG%@@:/[WINW_]]G_(&C^]Z#M"$L`(0A*>T3-Z0`Q!TEZ1'E$_O="
M[0*P$+T`OX!4`0`@`0``8A0``)\-``"4$0``(TDD2G"U>42M]0!=AK"*6`WU
M`%,#K!0S$F@:8$_P``+^]\#L'$L-]8!60?(!`GM$`9,:2Q`V`2%[1`"0($;^
M]]SL($8Q1D_T@%+^]V3L!!ZXOP`E"MM@'/[WC.P%1BBQ,48B1O[W"NP`(RM5
M#$D-]0!3"$H4,WE$BE@1:!IH44`$T2A&#?4`70:P<+W^]QSL,E0!`!@!``!J
M$0``5!$``,)3`0#_]ZR_+>GP3ZWUA%UB3(.P8DH%1GQ$8D@&K@WUA%.B6'A$
MB$8Q1@0S$F@:8$_P``+_]][\+R$$1BA&_O=Z[+"Q6$@I1GA$__=;_2A&5DD-
M]8134DH$,WE$BE@1:!IH44!`\)B`#?6$70.PO>CPCRA&_O=2[$U)>40'1D!&
M_O>T[()&`"C<T$I+W_@HD7M$!9.:^``P^43?^""!^$0`*U#0++%11B!&_O=H
MZP`H5=!01O[W,NP`\?\\AD8*ZPP#&O@,$"\I$-&"'JSK`PQ21!E&TAI/\``+
M@_@`L`/K#`X1^`$-$T0O*/;0>QR>1+[U@%^FV@WQA`LQ2@$A0T9Z1%A&`9)/
M](!2`I7-^`"@_O<B[#)&648#(/[WANPHN3-I`_1P0[/U`$\BT"5)`"!Y1/[W
M7.R"1KKQ``^"T)KX`#``*Z[1'+,C>"XK!-#=^!2@3_`!#LGG8W@`*_?1&DD`
M('E$_O="[()&NO$`#^;1:.<!(5A&_O<T[``HUM$32%E&>$3_][[\6$;^]TCK
M7^?*1D_P`0ZIY_[W1NN`4P$`&`$``-@0``#`$```/E,!`)X0``#<#P``U`\`
M`'X0```D$```Z`\``+8/``"&#P```W@[L4(<+RL(OQ!&$O@!.P`K^-%P1P"_
M$+6XLP-X!$:CL_[WE.M#'B-$G$(XOQI&`],QX*)"$T8NT!-&$O@!&2\I]]"<
M0B?2`3N<0B;0&G@O*OG1`3L"X!%X+RD$T9Q"&D8#\?\S]],2&Y,<L_6`7XB_
M`"`)V!%((48!,D_T@%-X1`1&_O?:ZB!&$+T,2+WH$$!X1/[WV+J<0MO1&W@O
M*P70"$B]Z!!`>$3^]\VZ!DB]Z!!`>$3^]\>Z`+_L4@$`"@X``*P.``#H#0``
M1TKPM7I$1TR-L$=+`JU\1$9/##0!KM-8?T0;:`N33_```P_,#\4/S`_%)&A`
M2'A$+(#_]]G[/TAX1/_WU?L^2'A$__?1^SU(>$3_]\W[/$AX1/_WR?L[2'A$
M__?%^SI(>$3_]\'[.4AX1/_WO?LX1O_WNOLV2'A$__>V^S5(>$3_][+[-$@Q
M1GA$__=E^QBQ`48X1O_WZ/LP2#%&>$3_]UO[`488L2Y(>$3_]]W[+4@Q1GA$
M__=0^P%&F+$J2'A$__?2^RE)*DAY1'A$__?,^RA*%4MZ1--8&F@+FUI`'=$-
ML/"])$@Q1GA$__<U^P%&(+$B2'A$__>W^^/G($D-\1D`"B)Y1/[W2.L`*-K1
M'4@-\2,!>$3_]Z?[T^?^]S;J^%`!`"Y-```8`0``Q`X``%X.``!@#@``8`X`
M`&0.``!D#@``;`X````.``!H#@``<@X``.X-``!L#@``;`X``"P-``!J#@``
MH@T``(0.``#J#0``*%`!`$0.``#<#0``/`X``+P-```62Q=)>T072@"U>408
M:(.PBEA#'!)H`9)/\``""M`22A!+>D336!IH`9M:0!/1`[!=^`3[#4AI1GA$
M__?)^C"Q`'@P*!B_`"@4OP$@`"`(2WM$&&#CY_[WUND`O\10`0!J3P$`&`$`
M`%)/`0`0#0``>%`!``BU_O>(Z?[W>ND`L0!H"+TC2O"U>D0C3H>P(TL$J7Y$
M!4;36#!&&V@%DT_P``/_]Y7Z*480L0-X!$9KN1M(>$3_]Q3[&DH82WI$TU@:
M:`6;6D`BT0>P\+W^]S[I`"CQT2A&_O<0Z@=&($;^]PSJ.$0",/[WY.D/2T_P
M_S(!(7M$`9,-2P*4>T0`E0=&_O<8ZCE&,$;_]^KZU.?^]WKI`+_L3@$`-@T`
M`!@!```6#0``N$X!``(,``#^"P``+>GP3P=&W_C\1BWM!(M\1-_X])8C'=_X
M]&;Y1`3Q$`Z3Z`<`K?4!3:6P*#1DK0WU`4,)E:7Q^`A9^`9@C#.E\>`,#*TV
M:!Y@3_``!BFNB.@'`+[H#P#?^+B6^42LZ`\`GN@#`(SH`P"4Z`<`AN@'`"E&
MW_B@!GA$__<2^B"Q`W@$1@`K0/""@?_W7/^"1@`H`/!+@5!&_O>8Z4```3#^
M]W#IFO@`,`9&B['?^&RV-$8:1OM$($8`DEM&3_#_,@$A`C3^]Z#I&O@!+P`J
M\M'?^$P&"9MX1*/QW`0"X%3X!`N(L2E&__?<^8)&`"CVT`-X`"OST/_WG/L`
M*._04$;^]^3H!$:HN4_P``I8^"I`?+$C>&NQ($8*\0$*__>)^P`H\]`@1O[W
MT.@`*.[0!$8`X``D($;^]TCI@D8P1O[W1.E01`#R!$I01O[W&NG?^-#%W_C0
M-4_P_S+\1`$A>T3-Z0$\W_C$-0.6>T0`E(!&_O=*Z4!&3_3@<?[W6.D!,`71
M_O<ZZ0)H$2I`\/*`*D9!1@,@_O>XZ01&(+/?^)`E`2$[:``F6?@"`-_XA"7-
M^`"`>D0`:/[W6.G?^'@5#?4!0]_X2"6,,WE$BE@1:!IH44!`\("",$8-]0%-
M);"][`2+O>CPCRMI`_1P0[/U@$_4T:YI_O<RZ(9"S]$K:</S"`.S]>!_R=%0
M1O[WNN@I1@9&W_@D!7A$__=#^0`H`/#&@#UH_O=2Z`%&*$;_]T/\!48`*`#P
MNX`H1O[WQN@#*(%&$=G?^/@4!#@H1'E$_??L[TBYN?$$#P#P[(&I1!GX!3PO
M*P#PYH'_]S/^0+D!1BA&_O>`Z`CND`H`*$#PF8#?^,`4W_C`!'E$W_B\='A$
MW_B\5/_WC?E_1/[WBNC?^+`TS?@`@'U$>T0!D]_XJ#1/\/\RW_BDI`$A>T3?
M^*"4`Y7Z1/E$`I`P1O[WG.@[1D=&F$84X/[WD.@#:!$K%]'^]VCH`30J1E-&
M`2'-^!"0S?@$@`"7S>D"!#!&_O>$Z$_TX'$P1O[WDNA#'`5&XM"X1D!&_?>N
M[]_X2`0Q1GA$__='^3!&__<6_D;G@T96^"L`F+,I1@OQ`0K_][+X!NN*!--&
M"+$#>&NY5/@$"RBS*48*\0$*__>D^--&`"CTT`-X`"OQT/WWL.\`*-_0@D:1
MYNY(`2$[:``F6?@``,WI`(+X2@!H>D3^]W#H%>?_]^+]($;]]YKO!D8.YPT@
MW_C(H_WW[N]3(_I$!D9^YCUH0N<)G4_P_S-O\!$"`B2E\00+`)3]]\;O&.Z0
M"EE&!B+]]S[O%?@$/".YF_@!,$,K`/!#@0`D`"(`(QCND`H`E`CN$&K]]Z[O
M"9VXH='I``%>1KBCT^D`(Z7QR`>I1@J4Q^D"`:7QD`''Z00C">X0&K.AT>D`
M`;.CT^D`(\WX+(#'Z08!LJ'1Z0`!Q^D((P`B`".\9\?I"B/'Z0PC1>DR`1CN
MD`I/]`!",4;]]_CN!!YUW=?I"@%/ZL0,/6M/ZN1[#.L``P:3"INB1M?X-,`'
MD]WI!B.+0@B_@D("T@$U3/$`#$_J6G*X;T+JRP)/ZEMS51G=Z0820^L,`[)&
M/6/'Z0H2>V.8NS\L*-VD\4`+"O&`""OP/P,*\4`.F$2N\4`$J?&0#"!H$#14
M^`P<9494^`@L#/$0#%3X!#QT10_%\=$X1O[WC/D$\4`.\$7FT4_JFQ1C'*OK
MA!0*ZX,:&>X0"E%&2",B1OWW"N^\9YCG&>X0.L#Q0`JB13%&J+^B1E)&&$3]
M]ZKNNV]31+MG0"N'T3A&I.L*!+)$_O=A^;/G"9L8[I`*H_&0!-WX+(#]]\[O
MO6HY:X`@Q?/%`ACN$&I3'"VZ."N1^H'YH%1OW</Q0`(`(>`8_?=:[SA&_O=`
M^2!&."(`(?WW4N_'Z1R5.$;^]S;Y"9C?^,BAH/$P"5#XR!P#1OI$H_%#!4Q&
M"@X)#`#X0QRY:##XR`P)ND/X0!PY:4"Z(_A"#`FZN&E#^#P<.6H`ND/X.`P)
MND/X-!P!X!7X`2L@1@"24T9/\/\R`2$"-/WW`N^I1?+16DA/\/\R64L!(7A$
MS?@(D`.0>T3-^`"`,$8!DP`CB?@H,%-+>T3]]^KN;N9_:``O/_06KCA&_??$
M[@,H?_80KDU)!#@X1'E$_??L[0`H"+\]1@7FX!C#\3@"`"']]^KNEN>;^`(P
M02M_]+BNF_@#,$,K?_2SKIOX!#!(*W_TKJZ;^`4P12M_]*FN3_#_,P"4&.Z0
M"F_P.0+]]UCN6488[I`**2+]]]#M-$LT3$_P_S)[1`&3,TM\1`$A,$9[1,WX
M"+#-^`"``Y3]]YKN'>;]]_[MK_,`@(FKS>\`````_MRZF`````!V5#(0````
M`/#ATL,``````2-%9P````"*3P$`*DX!`!@!``#J30$`,@L``/X+``!("@``
M;`L``'0*``!0"P``*`$``%@+``!^3`$`2`L``!H+```."@``C`D``#H)``"@
M"P``*@D``,P*``#4"@``@@L``(P(``!("0```@D````'```T"```N`4``$H'
M```@!P``&@4``(@'``"R!@``+>GP3YQ)+>T"BYQ*>42<2XI8A;![1`*N$F@#
MDD_P``*82@CN$&J=6"AH_?>R[@1&*&C]]Z[NE/AH(#%&`T:22(/X:2!X1/[W
M9?X8L0-X,2L`\.Z`__>R^BAH_?>:[HM)"R,!(GE$_??2[0`H`/#2@(=+`6E[
M1-7X`+!;:-'X&(`!*T7=W_@,HD_T@&F"2\#R(`GZ1``D>T0`DR;@`FAF'-KX
M"`#5^`"PD6A0^"9P">H!`;'U@&\(OQ%I#-!81@&3_?=F[@&;`"(9:`(C_?=N
M[=7X`+`!1CA&_??@[`";6VB8N0(TG$(T1@_:6$;]]U#N`",B1D%&_?<0[@-&
M`"C-T69+U?@`L'M$6VA9'J%"<-!81OWW/NYB20,C`2)Y1/WW=NT$1G"Q*&C]
M]S+N(VE=2AEH>D3]]RCM(VD;:)MH6P(`\8:`*&C]]R3N5TD#(P$B>43]]USM
M!$:`L51(&.X0&GA$_O?7_09&*&@`+F70_?<0[B-I,D89:/WW!NTH:/WW".X$
M1BAH_?<$[DE)`2)Y1/WW9NU'2GI$`48@1OWW].PH:/WW]NT`(ACN$!I"37U$
M`T9"2(/X:2!X1/[WJ_T$1NA@4+-/].!Q($;]]VKM0QP1*!B_`2M%V#E**$MZ
M1--8&F@#FUI`.]$%L+WL`HN]Z/"/`2N,W3-.`2181GY$`.`H:/WWQNU!1OWW
M<NQS:`$THT+UW-7X`+!ZYZAH__<J^P1&Z&``*,W1)TAX1/WW*NU#>``K/_00
MKPSG_?>J[2-+(FE[1)MH$&@9:/[W8_^5YRAH_?>>[2-I&6C]]S3M<>?]]W+L
M&DD#1AI((D9Y1'A$B6@):/WW!NVL1@$`&`$``*1&`0`@`0``+`0``+@%``#4
M1P$`MD<!`+)'`0!"1P$`"`4``/8$``#@!```R`(``*8$``"V!```FD8!`&0"
M``#<1`$`3$8!`"H$```&1@$`W$4!``H$```XM05&__<4^0-X!$8[L4(<+RL(
MOQ1&$O@!.P`K^-'_]R7Z`"T8OP`H`-$XO2MX`"O[T`9)($8$(GE$_?<@[0`H
M\]$H1KWH.$#^]T*^*`(``"WI^$,'1@Q.B$8,39%&?D3]]YKK?41V&[80"M`$
M/0`D5?@$/P$T2D9!1CA&F$>F0O;1O>CX@P"_;D(!`&1"`0!P1P"_`DM[1!MH
M_??ONP"_FD0!``A`+>D(@+WH`0`"`"]T;7``````+@```%!!4E]435!$25(`
M`%1%35!$25(`5$U0`%5315(`````55-%4DY!344`````+BX``"5S+R5S````
M+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`4$%27U1%
M35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)
M0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#
M04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(`
M``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%
M04X]```Q````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S
M)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD
M(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R
M`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M
M)74M)74E<P````!!4D=6`````!@```!P97)L`````#````!005(Z.E!A8VME
M<CHZ5D524TE/3@`````Q+C`T-P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@
M9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!E
M=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@
M,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P
M87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%
M3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M
M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T
M96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI
M.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@
M.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H
M+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`]
M(&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@
M/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]
M/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO
M<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R
M7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF
M:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M
M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*
M;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@
M)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D
M(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D
M=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z
M.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A
M;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@
M+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI
M;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL
M"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T
M87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I
M;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64[
M"FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*
M)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L
M("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N
M86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E
M=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL
M97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<
M;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@
M)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*
M?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0[
M"G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E
M96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D
M(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY
M("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F
M:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]
M?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S
M96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\
M*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN
M*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L
M;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%
M35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E
M>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD[
M"GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*
M8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U
M;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L
M:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[
M(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE
M9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E
M<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD
M(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE
M+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@
M)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL
M96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@
M)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N
M86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O
M;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*
M?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)
M3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@
M)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN
M<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I
M;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L
M)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA
M<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT[
M"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO
M;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?
M=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@
M<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'
M5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%0
M4%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R
M;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD
M05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T
M.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@
M97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B
M=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE
M(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]
M"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R
M(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@
M97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!
M4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.
M0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF
M="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@
M)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I
M;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B
M4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL
M;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G
M/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE
M("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+
M7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I
M;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A
M7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y
M("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N
M97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@
M)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D
M<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^
M('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T
M:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?
M:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O
M0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD
M9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T
M<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG
M>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F
M:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`
M:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]
M*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H
M+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL
M87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@
M>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI
M('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF
M("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@
M86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE
M*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@
M(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I
M;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N
M($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D
M(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&
M24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO
M=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%
M(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O
M;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D
M>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`[
M"FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[
M($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V
M97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`[
M"FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E
M<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X
M*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B
M*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H
M)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N
M9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H
M+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!
M4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70[
M"GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O
M9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D
M:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!
M4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN
M97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD
M0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q
M*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D[
M"B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM
M;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*
M?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\
M("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@
M+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L
M(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*
M?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@
M1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR
M97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@
M=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*
M<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y
M;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E
M<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT
M;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(
M86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL
M:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER
M92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#
M=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@
M4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP
M.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P
M='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/
M.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T
M7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T
M=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@
M4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z
M7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H
M(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@
M)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I
M;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I
M;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U
M<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-9
M4U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]
M("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E
M<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#
M3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2![
M"F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X
M+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F
M+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]
M"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q
M+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T
M.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S
M=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G
M-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F
M:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D
M8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E
M*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@
M)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE
M;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D
M:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]
M("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S
M+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M
M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D
M9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@
M9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@[
M"G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*
M?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\
M)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D
M<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I
M9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF
M(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]4
M14U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@
M>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O
M9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI
M=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2![
M"G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*
M?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/
M1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1?
M?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%
M3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI
M<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`]
M(")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6
M>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF
M("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E
M(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*
M)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%.
M/2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC````7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("``````0)S_?P$`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!Q&```,1@```$````!`````0``
M`,L!```!````&@(```$```!S`P``#````&@2```-````=#L``!D```"<?0$`
M&P````0````:````H'T!`!P````$````]?[_;[0!```%````6`D```8```"8
M`@``"@```.\$```+````$````!4``````````P```+1^`0`"``````(``!0`
M```1````%P```&@0```1````@`\``!(```#H````$P````@````>````"```
M`/O__V\!```(_O__;R`/``#___]O`P```/#__V](#@``^O__;Q``````````
M````````````````````````````````````````````````I'T!````````
M````=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02
M``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(`
M`'02``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``
M=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02``!T
M$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02
M``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``&$[````````````
M```````````````````````````````````````A.P```````)D5````````
M````````````````!(`!`/____^`.P``B#L```````",.P``D#L``)@[```<
M/```H#L```````"D.P``K#L```````#`/@``1T-#.B`H1&5B:6%N(#DN,BXQ
M+3@I(#DN,BXQ(#(P,3DP.3`Y`$$R````865A8FD``2@````%-RU!``8*!T$(
M`0D""@02!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`+FEN=&5R<``N
M;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN
M97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA
M;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`
M``````````````````````````````````````````````````````````L`
M```!`````@```%0!``!4`0``&0```````````````0`````````3````!P``
M``(```!P`0``<`$``"0```````````````0`````````)@````<````"````
ME`$``)0!```@```````````````$`````````#0```#V__]O`@```+0!``"T
M`0``Y`````4`````````!`````0````^````"P````(```"8`@``F`(``,`&
M```&`````P````0````0````1@````,````"````6`D``%@)``#O!```````
M```````!`````````$X```#___]O`@```$@.``!(#@``V`````4`````````
M`@````(```!;````_O__;P(````@#P``(`\``&`````&`````P````0`````
M````:@````D````"````@`\``(`/``#H````!0`````````$````"````',`
M```)````0@```&@0``!H$`````(```4````5````!`````@```!\`````0``
M``8```!H$@``:!(```P```````````````0`````````=P````$````&````
M=!(``'02```@`P`````````````$````!````((````!````!@```)@5``"8
M%0``W"4`````````````"`````````"(`````0````8```!T.P``=#L```@`
M``````````````0`````````C@````$````"````?#L``'P[``"F/P``````
M```````$`````````)8````!``!P@@```"1[```D>P``"`````T`````````
M!`````````"A`````0````(````L>P``+'L```0```````````````0`````
M````JP````X````#````G'T!`)Q]```$```````````````$````!````+<`
M```/`````P```*!]`0"@?0``!```````````````!`````0```##````!@``
M``,```"D?0$`I'T``!`!```&``````````0````(````S`````$````#````
MM'X!`+1^``!,`0`````````````$````!````-$````!`````P````"``0``
M@```0```````````````!`````````#7````"`````,```!`@`$`0(```!@0
M``````````````0`````````W`````$````P`````````$"````E````````
M```````!`````0```.4````#``!P``````````!E@```,P``````````````
M`0`````````!`````P``````````````F(```/4```````````````$`````
#````
